==> java-cxf-spring-server-generator-0.11.0.tgz: package/test-output/junit5/operations-v2.yml/src/main/java/com/example/model/Test1.java <==
package com.example.model;

@io.swagger.annotations.ApiModel(value = "Test1")
@javax.xml.bind.annotation.XmlRootElement(name = "Test1")
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-02-17T03:31:54.409Z")
public class Test1 implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.Integer size = null;
	
	/**
	 */
	public Test1 name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Test1 size(java.lang.Integer size) {
		setSize(size);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("size")
	public java.lang.Integer getSize() {
		return this.size;
	}
	public void setSize(java.lang.Integer size) {
		this.size = size;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Test1 test1 = (Test1) o;
		return java.util.Objects.equals(this.name, test1.name) &&
				java.util.Objects.equals(this.size, test1.size);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.size);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Test1 {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    size: ").append(toIndentedString(this.size)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.11.1.tgz: package/test-output/junit5/operations-v2.yml/src/main/java/com/example/model/Test1.java <==
package com.example.model;

@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-03-09T02:58:36.296Z")
@io.swagger.annotations.ApiModel(value = "Test1")
@javax.xml.bind.annotation.XmlRootElement(name = "Test1")
public class Test1 implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.Integer size = null;
	
	/**
	 */
	public Test1 name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Test1 size(java.lang.Integer size) {
		setSize(size);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("size")
	public java.lang.Integer getSize() {
		return this.size;
	}
	public void setSize(java.lang.Integer size) {
		this.size = size;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Test1 test1 = (Test1) o;
		return java.util.Objects.equals(this.name, test1.name)
				&& java.util.Objects.equals(this.size, test1.size);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.size);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Test1 {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    size: ").append(toIndentedString(this.size)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
